@@ -1,13 +1,23 @@
-#!/usr/bin/env texlua
 -----------------------------------------------------------------------
 --         FILE:  luaotfload-diagnostics.lua
---  DESCRIPTION:  functionality accessible by the --diagnose option
+--  DESCRIPTION:  part of luaotfload-tool / functionality accessible by the --diagnose option
 -- REQUIREMENTS:  luaotfload-tool.lua
---       AUTHOR:  Philipp Gesang (Phg), <phg42.2a@gmail.com>
---      VERSION:  2.5
---     MODIFIED:  2014-01-02 21:23:06+0100
+--       AUTHOR:  Philipp Gesang <phg@phi-gamma.net>
 -----------------------------------------------------------------------
---
+
+local ProvidesLuaModule = { 
+    name          = "luaotfload-diagnostics",
+    version       = "2.94",       --TAGVERSION
+    date          = "2018-12-19", --TAGDATE
+    description   = "luaotfload-tool submodule / diagnostics",
+    license       = "GPL v2.0"
+}
+
+if luatexbase and luatexbase.provides_module then
+  luatexbase.provides_module (ProvidesLuaModule)
+end  
+
+
 local names                    = fonts.names
 
 local kpse                     = require "kpse"
@@ -173,6 +183,11 @@ local get_permissions = function (t, location)
         location = lpegmatch (stripslashes, location)
     end
     local attributes = lfsattributes (location)
+    if not attributes then
+        print""
+        print("attr", location, attributes)
+        os.exit()
+    end
 
     if not attributes and t == "f" then
         attributes = get_tentative_attributes (location)
@@ -240,12 +255,10 @@ local check_conformance = function (spec, permissions, errcnt)
     return errcnt
 end
 
-local desired_permissions
 local init_desired_permissions = function ()
-    inspect(config.luaotfload.paths)
     local paths = config.luaotfload.paths
-    desired_permissions = {
-        { "d", {"r","w"}, function () return caches.getwritablepath () end },
+    return {
+        { "d", {"r","w"}, function () return caches.getwritablepath ("", "") end },
         { "d", {"r","w"}, paths.prefix },
         { "f", {"r","w"}, paths.index_path_lua .. ".gz" },
         { "f", {"r","w"}, paths.index_path_luc },
@@ -256,7 +269,7 @@ end
 
 local check_permissions = function (errcnt)
     out [[=============== file permissions ==============]]
-    if not desired_permissions then init_desired_permissions () end
+    local desired_permissions = init_desired_permissions ()
     for i = 1, #desired_permissions do
         local t, spec, path = unpack (desired_permissions[i])
         if type (path) == "function" then
@@ -655,27 +668,27 @@ local diagnose = function (job)
               you may sleep well.")
         return true, false
     end
-    out (         [[===============================================
-                                        WARNING
-                    ===============================================
+    out (             [[===============================================
+                                            WARNING
+                        ===============================================
 
-                    The diagnostic detected %d errors.
+                        The diagnostic detected %d errors.
 
-                    This version of luaotfload may have been
-                    tampered with. Modified versions of the
-                    luaotfload source are unsupported. Read the log
-                    carefully and get a clean version from CTAN or
-                    github:
+                        This version of luaotfload may have been
+                        tampered with. Modified versions of the
+                        luaotfload source are unsupported. Read the log
+                        carefully and get a clean version from CTAN or
+                        github:
 
-                        × http://www.ctan.org/pkg/luaotfload 
-                        × https://github.com/lualatex/luaotfload/releases
+                            × http://www.ctan.org/pkg/luaotfload 
+                            × https://github.com/lualatex/luaotfload/releases
 
-                    If you are uncertain as to how to proceed, then
-                    ask on the lualatex mailing list:
+                        If you are uncertain as to how to proceed, then
+                        ask on the lualatex mailing list:
 
-                        http://www.tug.org/mailman/listinfo/lualatex-dev
+                            http://www.tug.org/mailman/listinfo/lualatex-dev
 
-                    ===============================================
+                        ===============================================
 ]],          errcnt)
     return true, false
 end
